
/* Generated data (by glib-mkenums) */

#ifndef __CHAMPLAIN_ENUM_TYPES_H__
#define __CHAMPLAIN_ENUM_TYPES_H__ 1

#include <glib-object.h>

G_BEGIN_DECLS

#include <champlain/champlain-defines.h>
#define CHAMPLAIN_TYPE_STATE champlain_state_get_type()
GType champlain_state_get_type (void);
#include <champlain/champlain-view.h>
#define CHAMPLAIN_TYPE_SCROLL_MODE champlain_scroll_mode_get_type()
GType champlain_scroll_mode_get_type (void);
#include <champlain/champlain-selection-layer.h>
#define CHAMPLAIN_TYPE_SELECTION_MODE champlain_selection_mode_get_type()
GType champlain_selection_mode_get_type (void);
#include <champlain/champlain-map-source.h>
#define CHAMPLAIN_TYPE_MAP_PROJECTION champlain_map_projection_get_type()
GType champlain_map_projection_get_type (void);
G_END_DECLS

#endif /* __CHAMPLAIN_ENUM_TYPES_H__ */

/* Generated data ends here */

